@@ -1,18 +1,18 @@
-/*  Lzip - LZMA lossless data compressor
-    Copyright (C) 2008-2017 Antonio Diaz Diaz.
+/* Lzip - LZMA lossless data compressor
+   Copyright (C) 2008-2025 Antonio Diaz Diaz.
 
-    This program is free software: you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation, either version 2 of the License, or
-    (at your option) any later version.
+   This program is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 2 of the License, or
+   (at your option) any later version.
 
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
+   You should have received a copy of the GNU General Public License
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
 #define _FILE_OFFSET_BITS 64
@@ -42,9 +42,8 @@ int LZ_encoder::get_match_pairs( Pair * pairs )
     if( len_limit < 4 ) return 0;
     }
 
-  int maxlen = 0;
+  int maxlen = 3;			// only used if pairs != 0
   int num_pairs = 0;
-  const int pos1 = pos + 1;
   const int min_pos = ( pos > dictionary_size ) ? pos - dictionary_size : 0;
   const uint8_t * const data = ptr_to_current_pos();
 
@@ -57,32 +56,31 @@ int LZ_encoder::get_match_pairs( Pair * pairs )
 
   if( pairs )
     {
-    int np2 = prev_positions[key2];
-    int np3 = prev_positions[key3];
+    const int np2 = prev_positions[key2];
+    const int np3 = prev_positions[key3];
     if( np2 > min_pos && buffer[np2-1] == data[0] )
       {
       pairs[0].dis = pos - np2;
-      pairs[0].len = maxlen = 2;
+      pairs[0].len = maxlen = 2 + ( np2 == np3 );
       num_pairs = 1;
       }
     if( np2 != np3 && np3 > min_pos && buffer[np3-1] == data[0] )
       {
       maxlen = 3;
-      np2 = np3;
-      pairs[num_pairs].dis = pos - np2;
-      ++num_pairs;
+      pairs[num_pairs++].dis = pos - np3;
       }
     if( num_pairs > 0 )
       {
-      const int delta = pos1 - np2;
+      const int delta = pairs[num_pairs-1].dis + 1;
       while( maxlen < len_limit && data[maxlen-delta] == data[maxlen] )
         ++maxlen;
       pairs[num_pairs-1].len = maxlen;
+      if( maxlen < 3 ) maxlen = 3;
       if( maxlen >= len_limit ) pairs = 0;	// done. now just skip
       }
-    if( maxlen < 3 ) maxlen = 3;
     }
 
+  const int pos1 = pos + 1;
   prev_positions[key2] = pos1;
   prev_positions[key3] = pos1;
   int newpos1 = prev_positions[key4];
@@ -169,7 +167,7 @@ void LZ_encoder::update_distance_prices()
   }
 
 
-/* Returns the number of bytes advanced (ahead).
+/* Return the number of bytes advanced (ahead).
    trials[0]..trials[ahead-1] contain the steps to encode.
    ( trials[0].dis4 == -1 ) means literal.
    A match/rep longer or equal than match_len_limit finishes the sequence.
@@ -301,7 +299,7 @@ int LZ_encoder::sequence_optimizer( const int reps[num_rep_distances],
       cur_state = trials[prev_index].state;
       if( prev_index + 1 == cur )			// len == 1
         {
-        if( dis4 == 0 ) cur_state.set_short_rep();
+        if( dis4 == 0 ) cur_state.set_shortrep();
         else cur_state.set_char();			// literal
         }
       else if( dis4 < num_rep_distances ) cur_state.set_rep();
@@ -479,8 +477,8 @@ int LZ_encoder::sequence_optimizer( const int reps[num_rep_distances],
 bool LZ_encoder::encode_member( const unsigned long long member_size )
   {
   const unsigned long long member_size_limit =
-    member_size - File_trailer::size - max_marker_size;
-  const bool best = ( match_len_limit > 12 );
+    member_size - Lzip_trailer::size - max_marker_size;
+  const bool best = match_len_limit > 12;
   const int dis_price_count = best ? 1 : 512;
   const int align_price_count = best ? 1 : dis_align_size;
   const int price_count = ( match_len_limit > 36 ) ? 1013 : 4093;
@@ -491,7 +489,7 @@ bool LZ_encoder::encode_member( const unsigned long long member_size )
   State state;
   for( int i = 0; i < num_rep_distances; ++i ) reps[i] = 0;
 
-  if( data_position() != 0 || renc.member_position() != File_header::size )
+  if( data_position() != 0 || renc.member_position() != Lzip_header::size )
     return false;				// can be called only once
 
   if( !data_finished() )			// encode first byte
@@ -531,7 +529,7 @@ bool LZ_encoder::encode_member( const unsigned long long member_size )
       const int len = trials[i].price;
       int dis = trials[i].dis4;
 
-      bool bit = ( dis < 0 );
+      bool bit = dis < 0;
       renc.encode_bit( bm_match[state()][pos_state], !bit );
       if( bit )					// literal byte
         {
@@ -550,11 +548,11 @@ bool LZ_encoder::encode_member( const unsigned long long member_size )
         {
         crc32.update_buf( crc_, ptr_to_current_pos() - ahead, len );
         mtf_reps( dis, reps );
-        bit = ( dis < num_rep_distances );
+        bit = dis < num_rep_distances;
         renc.encode_bit( bm_rep[state()], bit );
         if( bit )				// repeated match
           {
-          bit = ( dis == 0 );
+          bit = dis == 0;
           renc.encode_bit( bm_rep0[state()], !bit );
           if( bit )
             renc.encode_bit( bm_len[state()][pos_state], len > 1 );
@@ -564,7 +562,7 @@ bool LZ_encoder::encode_member( const unsigned long long member_size )
             if( dis > 1 )
               renc.encode_bit( bm_rep2[state()], dis > 2 );
             }
-          if( len == 1 ) state.set_short_rep();
+          if( len == 1 ) state.set_shortrep();
           else
             {
             renc.encode_len( rep_len_model, len, pos_state );
